import {Component} from '@angular/core';
import {CookieService} from 'ngx-cookie-service';
import {MenuItem} from 'primeng/api';
import {MenubarModule} from 'primeng/menubar';
import {ToastModule} from 'primeng/toast';
import {Author} from '../model/author';

@Component({
  selector: 'app-header',
  standalone: true,
  imports: [
    MenubarModule,
    ToastModule
  ],
  templateUrl: './header.component.html',
  styleUrl: './header.component.css'
})
export class HeaderComponent {
  actualAuthor: Author | undefined;
  items: MenuItem[] = [];

  constructor(private cookieService: CookieService) {
    if (this.cookieService.get('author')) {
      this.actualAuthor = JSON.parse(this.cookieService.get('author'));
      this.items = [
        {
          label: 'Accueil',
          icon: 'pi pi-home',
          routerLink: '/'
        },
        {
          label: 'Mes posts',
          icon: 'pi pi-file-edit',
          items: [
            {
              label: 'Ajouter un post',
              icon: 'pi pi-plus',
              routerLink: 'new-post'
            },
            {
              label: 'Voir mes posts',
              icon: 'pi pi-eye',
              routerLink: ['posts', `${this.actualAuthor?.id}`]
            }
          ]
        },
        {
          label: `${this.actualAuthor?.name.toUpperCase()}`,
          icon: 'pi pi-user',
          items: [
            {
              label: 'Voir mon profil',
              icon: 'pi pi-user',
              routerLink: [`/profile`, `${this.actualAuthor?.id}`]
            },
            {
              label: 'Se déconnecter',
              icon: 'pi pi-sign-out',
              routerLink: '/logout'
            }
          ]
        }
      ];
    } else {
      this.items = [
        {
          label: 'Accueil',
          icon: 'pi pi-home',
          routerLink: '/'
        },
        {
          label: "S'authentifier",
          icon: 'pi pi-sign-in',
          items: [
            {
              label: 'Se connecter',
              icon: 'pi pi-sign-in',
              routerLink: '/login'
            },
            {
              label: "S'inscrire",
              icon: 'pi pi-user-plus',
              routerLink: '/register'
            }
          ]
        }
      ];
    }
  }
}
